@@ -620,17 +620,9 @@ nsIPCService::NewStringChannel(nsIURI* aURI, const nsACString &aContentType,
   nsresult rv;
 
   DEBUG_LOG(("nsIPCService::NewStringChannel:\n"));
-
-  /* not supported with Moz1.5a anymore:
-    nsCOMPtr<nsISupports> supports;
-   */
-
-  nsCOMPtr<nsIInputStream> supports;
-  rv = NS_NewCharInputStream(getter_AddRefs(supports), aData);
-  if (NS_FAILED(rv) || !supports) return rv;
-
-  nsCOMPtr<nsIInputStream> inputStream = do_QueryInterface(supports);
-  if (!inputStream) return NS_ERROR_FAILURE;
+  nsCOMPtr<nsIInputStream> inputStream;
+  rv = NS_NewCharInputStream(getter_AddRefs(inputStream), aData);
+  if (NS_FAILED(rv)) return rv;
 
   nsCAutoString contentType(aContentType);
   nsCAutoString contentCharset(aContentCharset);
