@@ -210,8 +210,8 @@ nsPipeChannel::Init(nsIURI* aURI,
     if (NS_FAILED(rv)) return rv;
 
     nsXPIDLCString contentType;
-    rv = MIMEService->GetTypeFromURI(url, getter_Copies(contentType));
-    if (contentType) {
+    rv = MIMEService->GetTypeFromURI(url, contentType);
+    if (NS_SUCCEEDED(rv) && contentType) {
       mContentType.Assign(contentType);
     }
 
